Module parser

Module parser 

csv+ Parser

A recursive descent, single-threaded CSV parser. This aims to be a CSV-compliant implementation of RFC 4180, however there are some additional features:

  • Multiline-field support. A \ character preceding a newline will parse as if the newline were not there.
  • Record comments. (A # at the beginning of the line comments out the whole record.)
  • Maintains a mapping of parsed positions to their original location in the source code.

Terminology

  • record - a row of data. typically a single line, unless it’s split across multiple lines
  • field - a single value from the record.

References

Structs

Parser

Functions

parse
Parse a given string and return the Cells.